@@ -436,5 +436,9 @@ class EndpointServiceGrpcTransport(EndpointServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("EndpointServiceGrpcTransport",)
