@@ -119,6 +119,8 @@ from .explanation import (
     Attribution,
     BlurBaselineConfig,
     Examples,
+    ExamplesOverride,
+    ExamplesRestrictionsNamespace,
     Explanation,
     ExplanationMetadataOverride,
     ExplanationParameters,
@@ -127,6 +129,8 @@ from .explanation import (
     FeatureNoiseSigma,
     IntegratedGradientsAttribution,
     ModelExplanation,
+    Neighbor,
+    Presets,
     SampledShapleyAttribution,
     SmoothGradConfig,
     XraiAttribution,
@@ -414,6 +418,9 @@ from .model_service import (
     ListModelVersionsRequest,
     ListModelVersionsResponse,
     MergeVersionAliasesRequest,
+    UpdateExplanationDatasetOperationMetadata,
+    UpdateExplanationDatasetRequest,
+    UpdateExplanationDatasetResponse,
     UpdateModelRequest,
     UploadModelOperationMetadata,
     UploadModelRequest,
@@ -650,6 +657,8 @@ __all__ = (
     "Attribution",
     "BlurBaselineConfig",
     "Examples",
+    "ExamplesOverride",
+    "ExamplesRestrictionsNamespace",
     "Explanation",
     "ExplanationMetadataOverride",
     "ExplanationParameters",
@@ -658,6 +667,8 @@ __all__ = (
     "FeatureNoiseSigma",
     "IntegratedGradientsAttribution",
     "ModelExplanation",
+    "Neighbor",
+    "Presets",
     "SampledShapleyAttribution",
     "SmoothGradConfig",
     "XraiAttribution",
@@ -888,12 +899,16 @@ __all__ = (
     "ListModelVersionsRequest",
     "ListModelVersionsResponse",
     "MergeVersionAliasesRequest",
+    "UpdateExplanationDatasetOperationMetadata",
+    "UpdateExplanationDatasetRequest",
+    "UpdateExplanationDatasetResponse",
     "UpdateModelRequest",
     "UploadModelOperationMetadata",
     "UploadModelRequest",
     "UploadModelResponse",
     "DeleteOperationMetadata",
     "GenericOperationMetadata",
+    "PipelineFailurePolicy",
     "PipelineJob",
     "PipelineJobDetail",
     "PipelineTaskDetail",
