@@ -19,6 +19,7 @@ from google.cloud.aiplatform_v1beta1.types import artifact
 from google.cloud.aiplatform_v1beta1.types import context
 from google.cloud.aiplatform_v1beta1.types import encryption_spec as gca_encryption_spec
 from google.cloud.aiplatform_v1beta1.types import execution as gca_execution
+from google.cloud.aiplatform_v1beta1.types import pipeline_failure_policy
 from google.cloud.aiplatform_v1beta1.types import pipeline_state
 from google.cloud.aiplatform_v1beta1.types import value as gca_value
 from google.protobuf import struct_pb2  # type: ignore
@@ -154,6 +155,14 @@ class PipelineJob(proto.Message):
                 ``PipelineJob.pipeline_spec.schema_version`` 2.1.0, such as
                 pipelines built using Kubeflow Pipelines SDK 1.9 or higher
                 and the v2 DSL.
+            failure_policy (google.cloud.aiplatform_v1beta1.types.PipelineFailurePolicy):
+                Represents the failure policy of a pipeline. Currently, the
+                default of a pipeline is that the pipeline will continue to
+                run until no more tasks can be executed, also known as
+                PIPELINE_FAILURE_POLICY_FAIL_SLOW. However, if a pipeline is
+                set to PIPELINE_FAILURE_POLICY_FAIL_FAST, it will stop
+                scheduling any new tasks when a task has failed. Any
+                scheduled tasks will continue to completion.
         """
 
         parameters = proto.MapField(
@@ -172,6 +181,11 @@ class PipelineJob(proto.Message):
             number=3,
             message=struct_pb2.Value,
         )
+        failure_policy = proto.Field(
+            proto.ENUM,
+            number=4,
+            enum=pipeline_failure_policy.PipelineFailurePolicy,
+        )
 
     name = proto.Field(
         proto.STRING,
